@@ -1,15 +1,15 @@
 
+# This file was created by mkconfig.rb when ruby was built.  Any
+# changes made to this file will be lost the next time ruby is built.
+
 module Config
+  RUBY_VERSION == "1.6.8" or
+    raise "ruby lib version (1.6.8) doesn't match executable version (#{RUBY_VERSION})"
 
-  RUBY_VERSION == "1.6.7" or
-    raise "ruby lib version (1.6.7) doesn't match executable version (#{RUBY_VERSION})"
-
-# This file was created by configrb when ruby was built. Any changes
-# made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
-  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.7"
+  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.8/ruby16"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -28,14 +28,14 @@ module Config
   CONFIG["sysconfdir"] = "$(prefix)/etc"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["localstatedir"] = "$(prefix)/var"
-  CONFIG["libdir"] = "$(exec_prefix)/lib"
-  CONFIG["includedir"] = "$(prefix)/include"
+  CONFIG["libdir"] = "/usr/local/i586-pc-msdosdjgpp/lib"
+  CONFIG["includedir"] = "/usr/local/i586-pc-msdosdjgpp/include"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["infodir"] = "$(prefix)/info"
   CONFIG["mandir"] = "$(prefix)/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "7"
+  CONFIG["TEENY"] = "8"
   CONFIG["host"] = "i586-pc-msdosdjgpp"
   CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
   CONFIG["host_cpu"] = "i586"
@@ -53,6 +53,9 @@ module Config
   CONFIG["build_os"] = "linux-gnu"
   CONFIG["CC"] = "gcc"
   CONFIG["CPP"] = "gcc -E"
+  CONFIG["GNU_LD"] = "yes"
+  CONFIG["CPPOUTFILE"] = ""
+  CONFIG["OUTFLAG"] = "-o"
   CONFIG["YACC"] = "bison -y"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["AR"] = "ar"
@@ -64,7 +67,7 @@ module Config
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
   CONFIG["OBJEXT"] = "o"
-  CONFIG["LIBOBJS"] = "crypt.o flock.o vsnprintf.o strtod.o"
+  CONFIG["LIBOBJS"] = "crypt.o flock.o vsnprintf.o"
   CONFIG["ALLOCA"] = ""
   CONFIG["XLDFLAGS"] = ""
   CONFIG["DLDFLAGS"] = ""
@@ -76,7 +79,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup.dj"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.7/dobj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.8/d.obj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "ld"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
@@ -93,13 +96,13 @@ module Config
   CONFIG["MAINLIBS"] = ""
   CONFIG["arch"] = "i386-msdosdjgpp"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "--srcdir=.. --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --cache=../../config.cache-djgpp"
+  CONFIG["configure_args"] = "--includedir=/usr/local/i586-pc-msdosdjgpp/include --libdir=/usr/local/i586-pc-msdosdjgpp/lib --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --with-opt-dir=/usr/local/i586-pc-msdosdjgpp --cache=./config.cache"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
-  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.7/dobj"
+  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.8/d.obj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
